@@ -3,20 +3,22 @@ use std::{
 	io::BufReader,
 };
 
+use serde::{ Serialize, Deserialize };
+
 use crate::{ Definition, ext::ReadExt };
 
 const X: usize = 64;
 const Y: usize = 64;
 const Z: usize = 4;
 
-#[derive(Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Default)]
+#[derive(Serialize, Deserialize, Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Default)]
 pub struct MapDefinition {
     pub region_x: u32,
     pub region_y: u32,
     pub data: Vec<Vec<Vec<MapData>>>
 }
 
-#[derive(Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Default)]
+#[derive(Serialize, Deserialize, Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Default)]
 pub struct MapData {
     pub height: u8,
     pub attr_opcode: u8,
