@@ -8,7 +8,9 @@ pub mod rs3;
 use crate::{ Cache, Store, Definition };
 
 /// The core of each Loader tasked with loading certain definitions.
-pub trait Loader<T: Definition>: Sized {
+pub trait Loader: Sized {
+    type Definition: Definition;
+
     fn new<S: Store>(cache: &Cache<S>) -> crate::Result<Self>;
-    fn load(&self, id: u16) -> Option<&T>;
+    fn load(&self, id: u32) -> Option<&Self::Definition>;
 }
\ No newline at end of file
