@@ -1,5 +1,6 @@
 //! Represents linked sectors in the main data file.
 
+use serde::{ Serialize, Deserialize };
 use nom::{
     combinator::rest,
 	number::complete::{
@@ -11,6 +12,7 @@ use nom::{
 };
 
 use crate::error::ReadError;
+use crate::arc::ArchiveRef;
 
 pub const SECTOR_HEADER_SIZE: usize = 8;
 pub const SECTOR_EXPANDED_HEADER_SIZE: usize = 10;
@@ -18,15 +20,18 @@ pub const SECTOR_DATA_SIZE: usize = 512;
 pub const SECTOR_EXPANDED_DATA_SIZE: usize = 510;
 pub const SECTOR_SIZE: usize = SECTOR_HEADER_SIZE + SECTOR_DATA_SIZE;
 
+pub type HeaderSize = usize;
+pub type DataSize = usize;
+
 /// Sector data for reading.
-#[derive(Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Default)]
+#[derive(Serialize, Deserialize, Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Default)]
 pub struct Sector<'a> {
 	pub header: SectorHeader,
 	pub data_block: &'a [u8]
 }
 
 /// Conveys the size of the header.
-#[derive(Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug)]
+#[derive(Serialize, Deserialize, Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug)]
 pub enum SectorHeaderSize {
 	/// Header consisting of 8 bytes.
 	Normal,
@@ -36,7 +41,7 @@ pub enum SectorHeaderSize {
 
 /// Contains the sector header for reading the next sector
 /// and validating the current sector.
-#[derive(Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Default)]
+#[derive(Serialize, Deserialize, Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Default)]
 pub struct SectorHeader {
 	pub archive_id: u32,
 	pub chunk: usize,
@@ -53,6 +58,45 @@ impl<'a> Sector<'a> {
 
 		Ok(Self { header, data_block })
 	}
+
+	/// Convenience function to create a `Sector` with a `Normal` header size.
+	#[inline]
+	pub fn from_normal_header(buffer: &'a [u8]) -> crate::Result<Self> {
+		Self::new(buffer, &SectorHeaderSize::Normal)
+	}
+
+	/// Convenience function to create a `Sector` with a `Expanded` header size.
+	#[inline]
+	pub fn from_expanded_header(buffer: &'a [u8]) -> crate::Result<Self> {
+		Self::new(buffer, &SectorHeaderSize::Expanded)
+	}
+}
+
+impl SectorHeaderSize {
+	/// Determines the size of the header for the given archive.
+	#[inline]
+	pub fn from_archive(archive: &ArchiveRef) -> Self {
+		if archive.id > std::u16::MAX.into() { 
+			Self::Expanded 
+		} else { 
+			Self::Normal 
+		}
+	}
+}
+
+/// Converts a `SectorHeaderSize` to the corresponding header size and data size.
+impl From<SectorHeaderSize> for (HeaderSize, DataSize) {
+	#[inline]
+	fn from(header_size: SectorHeaderSize) -> Self {
+		match header_size {
+			SectorHeaderSize::Normal => {
+				(SECTOR_HEADER_SIZE, SECTOR_DATA_SIZE)
+			},
+			SectorHeaderSize::Expanded => {
+				(SECTOR_EXPANDED_HEADER_SIZE, SECTOR_EXPANDED_DATA_SIZE)
+			}
+		}
+	}
 }
 
 impl<'a> SectorHeader {
@@ -112,14 +156,32 @@ impl Default for SectorHeaderSize {
 mod tests {
 	use super::*;
 
+	#[test]
+	fn test_header_size_normal() -> crate::Result<()> {
+		let archive = ArchiveRef{ id: u16::MAX as u32, index_id: 0, sector: 0, length: 0 };
+		let header_size = SectorHeaderSize::from_archive(&archive);
+
+		assert_eq!(header_size, SectorHeaderSize::Normal);
+
+		Ok(())
+	}
+
+	#[test]
+	fn test_header_size_expanded() -> crate::Result<()> {
+		let archive = ArchiveRef{ id: (u16::MAX as u32) + 1, index_id: 0, sector: 0, length: 0 };
+		let header_size = SectorHeaderSize::from_archive(&archive);
+
+		assert_eq!(header_size, SectorHeaderSize::Expanded);
+
+		Ok(())
+	}
+
 	#[test]
 	fn test_parse_header() -> crate::Result<()> {
 		let buffer = &[0, 0, 0, 0, 0, 0, 2, 255];
+		let (_, header) = SectorHeader::new(buffer, &SectorHeaderSize::Normal)?;
 
-		let expected = SectorHeader { archive_id: 0, chunk: 0, next: 2, index_id: 255 };
-		let (_, actual) = SectorHeader::new(buffer, &SectorHeaderSize::Normal)?;
-
-		assert_eq!(actual, expected);
+		assert_eq!(header, SectorHeader { archive_id: 0, chunk: 0, next: 2, index_id: 255 });
 
 		Ok(())
 	}
