@@ -16,23 +16,23 @@ use std::{
 
 use crate::{
     store::Store,
-    cache::{ MAIN_DATA, IDX_PREFIX, REFERENCE_TABLE},
-    idx::Index,
+    cache::{ MAIN_DATA, REFERENCE_TABLE },
+    idx::{ Index, IDX_PREFIX },
     ext::ReadExt,
     error::ReadError,
 };
 
 macro_rules! impl_iter_for_loader {
-    ($ldr:ident, $def:ty, $defs_field:ident) => {
+    ($ldr:ident, $def:ty) => {
         impl $ldr {
             #[inline]
             pub fn iter(&self) -> hash_map::Iter<'_, u32, $def> {
-                self.$defs_field.iter()
+                self.0.iter()
             }
 
             #[inline]
             pub fn iter_mut(&mut self) -> hash_map::IterMut<'_, u32, $def> {
-                self.$defs_field.iter_mut()
+                self.0.iter_mut()
             }
         }
 
@@ -42,7 +42,7 @@ macro_rules! impl_iter_for_loader {
 
             #[inline]
             fn into_iter(self) -> Self::IntoIter {
-                self.$defs_field.into_iter()
+                self.0.into_iter()
             }
         }
 
@@ -52,7 +52,7 @@ macro_rules! impl_iter_for_loader {
         
             #[inline]
             fn into_iter(self) -> Self::IntoIter {
-                self.$defs_field.iter()
+                self.0.iter()
             }
         }
 
@@ -62,7 +62,7 @@ macro_rules! impl_iter_for_loader {
 
             #[inline]
             fn into_iter(self) -> Self::IntoIter {
-                self.$defs_field.iter_mut()
+                self.0.iter_mut()
             }
         }
     };
@@ -110,7 +110,7 @@ pub mod djd2 {
 /// 
 /// ```
 /// # use std::{ fs::File, path::Path, collections::HashMap };
-/// # use rscache::arc::Archive;
+/// # use rscache::arc::ArchiveRef;
 /// use rscache::{ Store, util };
 /// 
 /// # fn main() -> rscache::Result<()> {
@@ -127,7 +127,7 @@ pub mod djd2 {
 /// 
 ///         Ok(Self {  })
 ///     }
-/// # fn read(&self, archive: &Archive) -> rscache::Result<Vec<u8>> {
+/// # fn read(&self, archive: &ArchiveRef) -> rscache::Result<Vec<u8>> {
 /// # unimplemented!()
 /// # }
 /// }
@@ -143,11 +143,15 @@ pub fn load_store<S: Store, P: AsRef<Path>>(path: P) -> crate::Result<S> {
 /// Loads all indices present in the cache folder.
 /// 
 /// The `u8` in `HashMap<u8, Index>` represents the id of the index.
+/// It loops through the directory searching for the reference table and
+/// every index that is compatible.
 /// 
 /// # Errors
 /// 
-/// Can return multiple errors: if the index couldnt be parsed or the index 
-/// couldn't be opened.
+/// Can return multiple errors: 
+/// - Reference table not found.
+/// - Index failed to parse. 
+/// - Index couldn't be opened.
 #[inline]
 pub fn load_indices<P: AsRef<Path>>(path: P) -> crate::Result<HashMap<u8, Index>> {
     let path = path.as_ref();
@@ -162,10 +166,10 @@ pub fn load_indices<P: AsRef<Path>>(path: P) -> crate::Result<HashMap<u8, Index>
 		let path = path.join(format!("{}{}", IDX_PREFIX, index_id));
 
 		if path.exists() {
-			let mut index = File::open(path)?;
-			let mut index_buffer = Vec::new();
+			let mut index_file = File::open(path)?;
+			let mut index_buffer = Vec::with_capacity(index_file.metadata()?.len() as usize);
 
-			index.read_to_end(&mut index_buffer)?;
+			index_file.read_to_end(&mut index_buffer)?;
 			indices.insert(index_id, Index::new(index_id, &index_buffer)?);
 		}
     }
