@@ -6,13 +6,13 @@ use crate::{
     Definition,
     Cache,
     codec,
-    arc,
+    arc::{ Archive, ArchiveFileGroup },
 };
 
 pub const ID_BLOCK_SIZE: usize = 256;
 
 macro_rules! impl_rs3_loader {
-   ($ldr:ident, $def:ty, $defs_field:ident, archive_id: $arc_id:expr) => {
+   ($ldr:ident, $def:ty, archive_id: $arc_id:expr) => {
         impl $ldr {
             #[inline]
             pub fn new<S: Store>(cache: &Cache<S>) -> crate::Result<Self> {
@@ -30,18 +30,18 @@ macro_rules! impl_rs3_loader {
 
             #[inline]
             fn new<S: Store>(cache: &Cache<S>) -> crate::Result<Self> {
-                let $defs_field = crate::util::rs3::parse_defs(cache, $arc_id)?;
+                let map = crate::util::rs3::parse_defs(cache, $arc_id)?;
 
-                Ok(Self { $defs_field })
+                Ok(Self(map))
             }
 
             #[inline]
             fn load(&self, id: u32) -> Option<&Self::Definition> {
-                self.$defs_field.get(&id)
+                self.0.get(&id)
             }
         }
 
-        impl_iter_for_loader!($ldr, $def, $defs_field);
+        impl_iter_for_loader!($ldr, $def);
    };
 }
 
@@ -64,11 +64,11 @@ macro_rules! impl_rs3_loader {
 /// # }
 /// ```
 #[inline]
-pub fn parse_defs<T: Definition, S: Store>(cache: &Cache<S>, archive_id: u32) -> crate::Result<HashMap<u32, T>> {
+pub fn parse_defs<D: Definition, S: Store>(cache: &Cache<S>, archive_id: u32) -> crate::Result<HashMap<u32, D>> {
     let buffer = cache.read(REFERENCE_TABLE, archive_id)?;
     let buffer = codec::decode(&buffer)?;
 
-    let archives = arc::parse_archive_data(&buffer)?;
+    let archives = Archive::parse(&buffer)?;
     let mut definitions = std::collections::HashMap::new();
     let mut base_id = 0;
 
@@ -76,11 +76,11 @@ pub fn parse_defs<T: Definition, S: Store>(cache: &Cache<S>, archive_id: u32) ->
         let buffer = cache.read(archive_id as u8, archive.id as u32)?;
         let buffer = codec::decode(&buffer)?;
 
-        let archive_data = arc::parse_content(&buffer, archive.entry_count)?;
+        let archive_group = ArchiveFileGroup::parse(&buffer, archive.entry_count)?;
 
-        for (index, data) in archive_data {
-            let id = base_id + archive.valid_ids[index as usize] as usize;
-            definitions.insert(id as u32, T::new(id as u32, &data)?);
+        for archive_file in archive_group {
+            let id = base_id + archive.valid_ids[archive_file.id as usize] as usize;
+            definitions.insert(id as u32, D::new(id as u32, &archive_file.data)?);
         }
 
         base_id += ID_BLOCK_SIZE;
